You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pdfbox.apache.org by ti...@apache.org on 2019/09/08 09:26:39 UTC

svn commit: r1866604 - /pdfbox/branches/2.0/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDExtendedGraphicsState.java

Author: tilman
Date: Sun Sep  8 09:26:39 2019
New Revision: 1866604

URL: http://svn.apache.org/viewvc?rev=1866604&view=rev
Log:
PDFBOX-4071: SonarQube fix

Modified:
    pdfbox/branches/2.0/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDExtendedGraphicsState.java

Modified: pdfbox/branches/2.0/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDExtendedGraphicsState.java
URL: http://svn.apache.org/viewvc/pdfbox/branches/2.0/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDExtendedGraphicsState.java?rev=1866604&r1=1866603&r2=1866604&view=diff
==============================================================================
--- pdfbox/branches/2.0/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDExtendedGraphicsState.java (original)
+++ pdfbox/branches/2.0/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDExtendedGraphicsState.java Sun Sep  8 09:26:39 2019
@@ -174,21 +174,19 @@ public class PDExtendedGraphicsState imp
     }
 
     /**
      * Returns the provided default value in case 'standard' valu
      * is <code>null</code>. To be used in cases unboxing may
      * lead to a NPE.
      *  
      * @param _value  'standard' value
      * @param _default  default value 
      * 
      * @return 'standard' value if not <code>null</code>
      *         otherwise default value
      */
-    private float defaultIfNull( Float _value, float _default ) 
+    private float defaultIfNull(Float standardValue, float defaultValue)
     {
-        return _value != null ? _value : _default;
+        return standardValue != null ? standardValue : defaultValue;
     }
-    
+
     /**
      * This will get the underlying dictionary that this class acts on.
      *
@@ -174,21 +174,19 @@ public class PDExtendedGraphicsState imp
 
     /**
-     * Returns the provided default value in case 'standard' valu
-     * is <code>null</code>. To be used in cases unboxing may
-     * lead to a NPE.
-     *  
-     * @param _value  'standard' value
-     * @param _default  default value 
-     * 
-     * @return 'standard' value if not <code>null</code>
-     *         otherwise default value
+     * Returns the provided default value in case 'standard' value is <code>null</code>. To be used
+     * in cases unboxing may lead to a NPE.
+     *
+     * @param standardValue 'standard' value
+     * @param defaultValue default value
+     *
+     * @return 'standard' value if not <code>null</code> otherwise default value
      */